@@ -25,8 +25,8 @@ class Shift_dayQuerySet(CommonManagetWithLookUpFieldsQuerySet):
 
 class Shift_dayManager(CommonManagetWithLookUpFieldsManager):
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
 
