@@ -1,8 +1,6 @@
 from django.db import connection
 
 from isc_common.auth.models.user import User
-from isc_common.auth.models.user_permission import User_permission
-from isc_common.auth.models.widgets_trees import Widgets_trees
 from isc_common.http.DSRequest import DSRequest
 from isc_common.http.RPCResponse import RPCResponseConstant
 from isc_common.json import StrToJson
@@ -10,6 +8,9 @@ from isc_common.json import StrToJson
 
 class GetPermissionRequest(DSRequest):
     def __init__(self, request):
+        from permission.models.widgets_trees import Widgets_trees
+        from permission.models.user_permission import User_permission
+
         DSRequest.__init__(self, request)
         data = self.get_data()
         id = data.get('id', None)
