@@ -1,6 +1,5 @@
 from isc_common.auth.http.ChangePassRequest import ChangePassRequest
 from isc_common.auth.http.Link2Group import Link2Group
-from isc_common.auth.http.LoginRequets import LoginRequest
 from isc_common.auth.http.LogoutRequets import LogoutRequest
 from isc_common.auth.http.UnLinkFromGroup import UnlinkFromGroup
 from isc_common.auth.http.copyPermission import CopyPermission
@@ -8,11 +7,6 @@ from isc_common.http.DSResponse import JsonResponseWithException
 from isc_common.http.response import JsonResponse
 
 
-@JsonResponseWithException(printing=False)
-def login(request):
-    return JsonResponse(LoginRequest(request).response)
-
-
 @JsonResponseWithException(printing=False)
 def logout(request):
     return JsonResponse(LogoutRequest(request).response)
