@@ -1,4 +1,10 @@
 class Dz:
+    dzchunkbyteoffset = None
+    dzchunkindex = None
+    dztotalchunkcount = None
+    dztotalfilesize = None
+    dzuuid = None
+
     def __init__(self, POST):
         for k, v in POST.dict().items():
             try:
