@@ -8,7 +8,7 @@ class DescriptionField(TextField, Field):
     def __init__(self, *args, **kwargs):
         kwargs.setdefault('null', True)
         kwargs.setdefault('blank', True)
-        kwargs.setdefault('db_index', True)
+        kwargs.setdefault('db_index', False)
         super().__init__(*args, **kwargs)
 
     def deconstruct(self):
