@@ -296,46 +296,46 @@ class DSRequest(RPCRequest):
     def get_username(self):
         return self.get_data().get('username')
 
-    def get_ids(self):
+    def get_ids(self, field_name='id'):
         multi, data_array = self.get_data_array()
         if data_array:
             if multi:
-                ids = [record.get('data').get('id') for record in data_array]
+                ids = [record.get('data').get(field_name) for record in data_array]
             else:
-                ids = [record.get('data').get('id') if record.get('data') else record.get('id') for record in data_array]
+                ids = [record.get('data').get(field_name) if record.get('data') else record.get(field_name) for record in data_array]
         else:
             ids = [0]
         return [id for id in ids if id is not None]
 
-    def get_tuple_ids(self):
+    def get_tuple_ids(self, field_name='id'):
         multi, data_array = self.get_data_array()
         if data_array:
             if multi:
-                ids = [(record.get('data').get('id'), record.get('visibleMode', 'none')) for record in data_array]
+                ids = [(record.get('data').get(field_name), record.get('visibleMode', 'none')) for record in data_array]
             else:
-                ids = [(record.get('data').get('id'), self.visibleMode) if record.get('data') else (record.get('id'), self.visibleMode) for record in data_array]
+                ids = [(record.get('data').get(field_name), self.visibleMode) if record.get('data') else (record.get(field_name), self.visibleMode) for record in data_array]
         else:
             ids = [(0, "none")]
         return ids
 
-    def get_olds_tuple_ids(self):
+    def get_olds_tuple_ids(self, field_name='id'):
         multi, data_array = self.get_data_array()
         if data_array:
             if multi:
-                ids = [(record.get('oldValues').get('id'), record.get('visibleMode', 'none')) for record in data_array]
+                ids = [(record.get('oldValues').get(field_name), record.get('visibleMode', 'none')) for record in data_array]
             else:
-                ids = [(record.get('oldValues').get('id'), self.visibleMode) if record.get('data') else (record.get('id'), self.visibleMode) for record in data_array]
+                ids = [(record.get('oldValues').get(field_name), self.visibleMode) if record.get('data') else (record.get(field_name), self.visibleMode) for record in data_array]
         else:
             ids = [(0, "none")]
         return ids
 
-    def get_old_ids(self):
+    def get_old_ids(self, field_name='id'):
         multi, data_array = self.get_data_array()
         if data_array:
             if multi:
-                ids = [record.get('oldValues').get('id') for record in data_array]
+                ids = [record.get('oldValues').get(field_name) for record in data_array]
             else:
-                ids = [record.get('oldValues').get('id') if record.get('oldValues') else record.get('id') for record in data_array]
+                ids = [record.get('oldValues').get(field_name) if record.get('oldValues') else record.get(field_name) for record in data_array]
         else:
             ids = [0]
         return [id for id in ids if id is not None]
