@@ -3,6 +3,13 @@ from isc_common.isc.data_binding.criterion import Criterion
 
 class AdvancedCriteria(Criterion):
     _constructor = None
+    criteria = []
+
+    def get_criterion(self, field_name):
+        if isinstance(self.criteria, list):
+            return list(filter(lambda x: x.fieldName == field_name, self.criteria))
+        else:
+            return None
 
     def __init__(self, **kwargs):
         lst = kwargs.get('lst')
