@@ -18,12 +18,34 @@ from isc_common.number import TryToInt
 logger = logging.getLogger(__name__)
 
 
+class ExtQuerySet(QuerySet):
+    def getOptional(self, *args, **kwargs):
+        try:
+            res = self.get(*args, **kwargs)
+            return res
+        except self.model.DoesNotExist:
+            return None
+
+
+class ExtManager(Manager):
+    def get_queryset(self):
+        return ExtQuerySet(self.model, using=self._db)
+
+    def getOptional(self, *args, **kwargs):
+        try:
+            res = self.get(*args, **kwargs)
+            return res
+        except self.model.DoesNotExist:
+            return None
+
+
 def lazy_bulk_fetch(max_obj, max_count, fetch_func, start=0):
     counter = start
     while counter < max_count:
         yield fetch_func()[counter:counter + max_obj]
         counter += max_obj
 
+
 class CommonQuerySet(QuerySet):
 
     def soft_restore(self):
