@@ -1,11 +1,12 @@
 import logging
 
-from django.db.models import TextField, Model
+from django.db.models import TextField, Model, BigAutoField
 
 logger = logging.getLogger(__name__)
 
 
 class Debug(Model):
+    id = BigAutoField(primary_key=True, verbose_name="Идентификатор")
     params = TextField(null=True, blank=True)
     text = TextField()
 
