@@ -103,8 +103,8 @@ class Model_images(AuditModel):
             if len(full_name_images) == 0 and file_name is not None:
                 if exception is True:
                     raise ImageNotFound(f'{file_name} : not found')
-                # else :
-                #     logger.debug( f'{file_name} : not found !!!' )
+                else:
+                    logger.error(f'{file_name} : not found !!!')
 
             for full_name_image in full_name_images:
                 if full_name_image is not None:
