@@ -18,8 +18,8 @@ class ProgressesQuerySet(AuditQuerySet):
 
 
 class ProgressesManager(AuditManager):
-    @staticmethod
-    def props():
+    @classmethod
+    def props(cls):
         return BitField(flags=(
             ('showCancel', 'Показать кнопку отменить процесс'),
         ), default=0, db_index=True)
@@ -39,8 +39,8 @@ class ProgressesManager(AuditManager):
                 props=proces.get('props')
             )
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'cnt': record.cnt,
             'deliting': record.deliting,
