@@ -44,14 +44,11 @@ class TreeAuditModelQuerySet(AuditQuerySet):
             limit = f'limit {limit}'
         else:
             limit = ''
-
         if id is not None:
             if isinstance(id, int):
                 id = tuple([id])
             elif isinstance(id, str):
-                id = tuple([int(id)])
-            elif isinstance(id, list):
-                id = tuple(id)
+                id = int(id)
             elif not isinstance(id, tuple):
                 raise Exception(f'id must be list or int')
 
@@ -77,7 +74,7 @@ class TreeAuditModelQuerySet(AuditQuerySet):
                             select {distinct} {fields} from r {where_clause1} {order_by_clause} limit %s offset %s
                         '''
             # logger.debug(f'sql: {sql_text}')
-            res = super().raw(sql_text, params=(id, end, start))
+            res = super().raw(sql_text, params=((id,), end, start))
         else:
             child_parent_value_str = f' = {child_parent_value}'
             if where_clause0 == '':
