@@ -1,5 +1,6 @@
 import os
 import shutil
+from pathlib import Path
 
 
 def mekeDirs(name, logger, mode=0o777, exist_ok=False):
@@ -22,3 +23,15 @@ def copyTwo(src, dst, follow_symlinks=True):
         return True
     except FileNotFoundError:
         return False
+
+
+def get_tmp_dir(base_dir=None):
+    if base_dir is None:
+        tmpdir = f'{str(Path.home())}{os.sep}tmp'
+    else:
+        tmpdir = f'{base_dir}{os.sep}tmp'
+
+    if os.path.exists(tmpdir) is False:
+        os.mkdir(tmpdir)
+
+    return tmpdir
