@@ -1,7 +1,7 @@
 from django.urls import path
 
 from isc_common.views import images
-from isc_common.views.images import User_UploadImage
+from isc_common.views.images import Images_Upload
 
 urlpatterns = [
 
@@ -12,6 +12,6 @@ urlpatterns = [
     path('Images/Lookup/', images.Images_Lookup),
     path('Images/Info/', images.Images_Info),
     path('Images/Copy', images.Images_Copy),
-    path('Images/Upload', User_UploadImage),
+    path('Images/Upload', Images_Upload),
 
 ]
