@@ -50,5 +50,5 @@ def Images_Copy(request):
 
 
 @JsonResponseWithException()
-def User_UploadImage(request):
+def Images_Upload(request):
     return JsonResponse(DSResponse_UploadImage(request).response)
