@@ -30,12 +30,12 @@ class LinkedList:
         return res
 
     def __str__(self):
-        if self.first != None:
+        if self.first is not None:
             current = self.first
 
             out = f'{self.__class__.__name__} [\n{self._fill_blanks(4)}{str(current)}\n'
 
-            while current.next != None:
+            while current.next is not None:
                 current = current.next
                 out += f'{self._fill_blanks(4)}{str(current)}\n'
             return f'{out}]'
@@ -49,11 +49,11 @@ class LinkedList:
     def length(self):
         self._length = 0
 
-        if self.first != None:
+        if self.first is not None:
             self._length += 1
             current = self.first
 
-            while current.next != None:
+            while current.next is not None:
                 current = current.next
                 self._length += 1
 
@@ -62,7 +62,7 @@ class LinkedList:
     # Добавление элементов в конец списка.
     def add(self, item):
         self._length += 1
-        if self.first == None:
+        if self.first is None:
             # self.first и self.last будут указывать на одну область памяти
             self.last = self.first = Node(item=item)
         else:
@@ -72,14 +72,14 @@ class LinkedList:
     # А не научиться ли нам вставлять эл-ты в начало списка?)
     def push(self, item):
         self._length += 1
-        if self.first == None:
+        if self.first is None:
             self.last = self.first = Node(item=item)
         else:
             self.first = Node(item=item, next=self.first)
 
     # Вставка в позицию
     def insert(self, pos, item):
-        if self.first == None:
+        if self.first is None:
             self.last = self.first = Node(item=item, next=None)
             return
 
@@ -90,11 +90,11 @@ class LinkedList:
         curr = self.first
         count = 0
 
-        while curr != None:
+        while curr is not None:
             count += 1
             if count == pos:
                 curr.next = Node(item=item, next=curr.next)
-                if curr.next.next == None:
+                if curr.next.next is None:
                     self.last = curr.next
                 break
             curr = curr.next
@@ -102,27 +102,27 @@ class LinkedList:
     # Удаление головного элемента
     def pop(self):
         oldhead = self.first
-        if oldhead == None:
+        if oldhead is None:
             return None
 
         self.first = oldhead.next
-        if self.first == None:
+        if self.first is None:
             self.last = None
 
         return oldhead.value
 
     # Удаление элемента из списка
     def Del(self, pos):
-        if (self.first == None):
+        if (self.first is None):
             return
         curr = self.first
         count = 0
         if pos == 0:
             self.first = self.first.next
             return
-        while curr != None:
+        while curr is not None:
             if count == pos:
-                if curr.next == None:
+                if curr.next is None:
                     self.last = curr
                 old.next = curr.next
                 break
@@ -137,14 +137,14 @@ class LinkedList:
 
     # Вставка элемента в отсортированный список
     def sorted_insert(self, item):
-        if self.first == None:
+        if self.first is None:
             self.first = Node(item, self.last)
             return
         if self.first.item > item:
             self.first = Node(item, self.first)
             return
         curr = self.first
-        while curr != None:
+        while curr is not None:
             if curr.value > item:
                 old.next = Node(item, curr)
                 return
@@ -154,12 +154,12 @@ class LinkedList:
 
     # удаление повторяющихся значений
     def remove_duplicates(self):
-        if (self.first == None):
+        if (self.first is None):
             return
         old = curr = self.first
-        while curr != None:
+        while curr is not None:
             _del = 0
-            if curr.next != None:
+            if curr.next is not None:
                 if curr.value == curr.next.value:
                     curr.next = curr.next.next
                     _del = 1
@@ -169,11 +169,11 @@ class LinkedList:
     def __getitem__(self, key):  # поддержка обращения по ключу
         length = 0
         current = None
-        if self.first != None:
+        if self.first is not None:
             current = self.first
-            # while key != length or current.next != None:
+            # while key != length or current.next is not None:
             while key != length:
-                if current.next != None:
+                if current.next is not None:
                     current = current.next
                     length += 1
                 else:
@@ -187,7 +187,7 @@ class LinkedList:
 
     def find(self, item, func_equal=None):
         curr = self.first
-        while curr != None:
+        while curr is not None:
             if func_equal:
                 res = func_equal(item, curr.item)
             else:
