@@ -1,6 +1,6 @@
 import logging
 
-from django.db.models import Model, BigAutoField
+from django.db.models import Model
 
 from isc_common.fields.related import ForeignKeyCascade
 from one_c.models.document_1c import Document_1c
@@ -10,7 +10,6 @@ logger = logging.getLogger(__name__)
 
 
 class Documents_param_cross_1c(Model):
-    id = BigAutoField(primary_key=True, verbose_name="Идентификатор")
     document = ForeignKeyCascade(Document_1c)
     param = ForeignKeyCascade(Documents_param_1c)
 
