@@ -1,5 +1,4 @@
 import logging
-import uuid
 from tempfile import TemporaryFile
 
 from django.core.files import File
@@ -8,10 +7,10 @@ from django.db import transaction
 from crypto.models.upload_file import DSResponse_UploadFile
 from isc_common.auth.models.user import User
 from isc_common.common import uuid4
+from isc_common.common.UploadItem import UploadItem
 from isc_common.common.functions import Common
 from isc_common.dropzone import Dz
 from isc_common.http.RPCResponse import RPCResponseConstant
-from kaf_pas.common.UploadItem import UploadItem
 
 logger = logging.getLogger(__name__)
 
