@@ -1,3 +1,4 @@
+from isc_common.common.functions import get_relation_field_name
 from isc_common.http.DSRequest import DSRequest
 from isc_common.http.DSResponse import DSResponseUpdate, DSResponseAdd, DSResponse, JsonResponseWithException
 from isc_common.http.RPCResponse import RPCResponseConstant
@@ -12,7 +13,7 @@ def Messages_view_Fetch(request):
     response = DSResponse(
         request=request,
         data=Messages_view.objects.
-            select_related('user', 'state', 'theme', 'to_whom', 'tma_user', 'importance').
+            select_related(*get_relation_field_name( model=Messages_view )).
             # filter().
             filter().
             get_range_rows1(
@@ -30,7 +31,7 @@ def Messages_view_FetchAdmin(request):
     response = DSResponse(
         request=request,
         data=Messages_admin_view.objects.
-            select_related('user', 'state', 'theme', 'to_whom', 'importance').
+            select_related(*get_relation_field_name( model=Messages_admin_view )).
             filter().
             get_range_rows1(
             request=request,
