@@ -15,8 +15,8 @@ class ChatsQuerySet(BaseRefQuerySet):
 
 class ChatsManager(BaseRefManager):
 
-    @staticmethod
-    def refresh_chat_menu(user, logger):
+    @classmethod
+    def refresh_chat_menu(cls, user, logger):
         from isc_common.auth.http.LoginRequets import LoginRequest
         message = dict(
             type='refresh_chat_menu',
@@ -31,8 +31,8 @@ class ChatsManager(BaseRefManager):
             logger=logger
         )
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'code': record.code,
